import QtQuick 2.4
import Ubuntu.Components 1.2
import Ubuntu.Components.ListItems 1.0 as UListItem
import Ubuntu.DownloadManager 0.1
import Ubuntu.Components.Popups 1.0
import Ubuntu.Content 1.1
import U1db 1.0 as U1db
import "data.js" as Data
import "components"

MainView {
    id: root
    property list<ContentItem> transferItemList
    property var contentTransfer
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "mainView"

    // Note! applicationName needs to match the "name" field of the click manifest
    applicationName: "vulgry.johangm90"

    width: units.gu(50)
    height: units.gu(75)

    Component {
        id: transferComponent
        ContentItem { }
    }

    // Transfer downloaded video
    Component {
        id: downloadDialog
        Download { }
    }

    Component {
        id: aboutPage
        AboutPage {}
    }

    U1db.Database {
        id: db
        path: "vulgry"
    }

    U1db.Document {
        id: themeDoc
        docId: 'theme'
        database: db
        create: true
        defaults: { 'theme': "Ambiance" }

        onContentsChanged: Theme.name = "Ubuntu.Components.Themes." + themeDoc.contents.theme
    }

    PageStack{
        id: pageStack
        Component.onCompleted: push(page0)
        Page {
            id: page0
            title: "Vulgry"
            visible: false
            head.actions: [
                Action {
                    text: i18n.tr("Search")
                    iconName: "search"
                    onTriggered: {
                        pageStack.push(sresult)
                        vgModel.clear()
                        squery.text=""
                        squery.forceActiveFocus()
                    }
                },
                Action {
                    text: i18n.tr("Theme")
                    iconName: (themeDoc.contents.theme == "Ambiance") ? "torch-on" : "torch-off"
                    onTriggered: themeDoc.contents =  { 'theme': ((themeDoc.contents.theme == "Ambiance") ? "SuruDark" : "Ambiance") }
                },
                Action {
                    text: i18n.tr("Donate")
                    iconName: "like"
                    onTriggered: Qt.openUrlExternally("https://life.indiegogo.com/fundraisers/help-me-to-get-an-ubuntu-phone/x/4138828")
                },
                Action {
                    text: i18n.tr("About")
                    iconName: "help"
                    onTriggered: pageStack.push(aboutPage)
                }
            ]

            Rectangle {
                id: url
                color: "transparent"
                anchors.fill: parent
                anchors.margins: units.gu(2)

                TextField {
                    id: tfurl
                    placeholderText: i18n.tr("Video URL")
                    width: parent.width
                }
            }

            Rectangle {
                id: process
                color: Qt.lighter("#0169c9", 2);
                width: units.gu(18)
                height: units.gu(18)
                radius: units.gu(9)
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter

                Rectangle {
                    color: "#0169c9"
                    width: units.gu(15)
                    height: units.gu(15)
                    radius: units.gu(7.5)
                    anchors.centerIn: parent

                    Text{
                        id: go
                        text: i18n.tr("<b>PROCESS</b>")
                        color: "#fff"
                        anchors.verticalCenter: parent.verticalCenter
                        anchors {
                            left: parent.left
                            right: parent.right
                        }
                        font.pointSize: units.gu(2)
                        wrapMode: Text.Wrap
                        horizontalAlignment:Text.AlignHCenter
                    }

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            if(tfurl.text!=''){
                                pageStack.push(page1)
                                Data.getLinks(tfurl.text);
                            }else{
                                console.log('error')
                            }
                        }
                    }
                }
            }
        }

        Page{
            id: sresult
            title: "Vulgry"
            visible: false
            head.contents: TextField {
                id: squery
                placeholderText: i18n.tr("Search...")
                anchors.fill: parent
                anchors.rightMargin: units.gu(2)
                anchors.topMargin: units.gu(1.5)
                anchors.bottomMargin: units.gu(1.5)
                Keys.onReturnPressed: {
                    if(squery.text!=''){
                        Data.getVG(squery.text);
                        squery.focus=false
                    }else{
                        console.log('error')
                    }
                }
            }

            Rectangle {
                color: "transparent"
                anchors {
                    fill: parent
                }
                ActivityIndicator {
                    id: sloader
                    anchors.centerIn: parent
                }
                Column{
                    id: scontainer
                    spacing: units.gu(1)
                    anchors {
                        fill: parent
                    }

                    ListModel {
                        id: vgModel
                    }

                    Item {
                        anchors.top: parent.top
                        anchors.bottom: parent.bottom
                        ListView {
                            id: vgList
                            clip: true
                            model: vgModel
                            width: scontainer.width
                            height: parent.height
                            boundsBehavior: Flickable.StopAtBounds
                            delegate: ListItem {
                                Rectangle {
                                    id: rect1
                                    color: "transparent"
                                    width: units.gu(9.2)
                                    height: units.gu(5.2)
                                    anchors.verticalCenter: parent.verticalCenter;
                                    anchors.left: parent.left;
                                    anchors.leftMargin: units.gu(1.6);

                                    Image {
                                        anchors.fill: parent
                                        fillMode: Image.PreserveAspectCrop
                                        source: simg
                                    }
                                }
                                Rectangle {
                                    color: "transparent"
                                    height: parent.height
                                    width: parent.width
                                    anchors.left: rect1.right;
                                    anchors.right: parent.right;
                                    anchors.leftMargin: units.gu(1.6);
                                    Label {
                                        text: stitle
                                        elide: Text.ElideRight
                                        anchors.verticalCenter: parent.verticalCenter
                                        anchors.right: parent.right
                                        anchors.left: parent.left
                                    }
                                }

                                onClicked: {
                                    pageStack.push(page1)
                                    Data.getLinks(surl);
                                }
                            }
                        }
                        Scrollbar {
                            flickableItem: vgList
                            align: Qt.AlignTrailing
                        }
                    }
                }
            }
        }

        Page{
            id: page1
            title: "Vulgry"
            visible: false

            Rectangle {
                color: "transparent"
                anchors {
                    fill: parent
                }
                ActivityIndicator {
                    id: activity
                    anchors.centerIn: parent
                }
                Column{
                    id: jgm
                    spacing: units.gu(1)
                    anchors {
                        topMargin: units.gu(2)
                        fill: parent
                    }

                    UbuntuShape {
                        id: thumbnailShape
                        width: units.gu(32)
                        height: units.gu(18)
                        anchors.horizontalCenter: parent.horizontalCenter
                        image: Image {
                            id: thumbnailImage
                            fillMode: Image.PreserveAspectFit
                            source: ""
                        }
                        visible: false
                    }

                    UListItem.ThinDivider {
                        id: divider1
                        visible: false
                        anchors.top: thumbnailShape.botton
                        anchors.topMargin: units.gu(2)
                    }

                    ListModel {
                        id: urlModel
                    }

                    Item {
                        anchors.top: divider1.bottom
                        anchors.bottom: parent.bottom
                        ListView {
                            id: urlView
                            clip: true
                            model: urlModel
                            width: jgm.width
                            height: parent.height
                            boundsBehavior: Flickable.StopAtBounds
                            delegate: ListItem {
                                property variant colors: ["#24c6d5", "#57dd86", "#ad7dcf", "#ff484d", "#fcba59"]
                                Component.onCompleted: {
                                    var color = index % colors.length
                                    rformat.color=colors[color]
                                }
                                contentItem.anchors {
                                    leftMargin: units.gu(2)
                                    rightMargin: units.gu(2)
                                    topMargin: units.gu(0.5)
                                    bottomMargin: units.gu(0.5)
                                }
                                Rectangle {
                                    id: rformat
                                    color: "#24c6d5"
                                    width: height
                                    height: parent.height
                                    radius: height/2
                                    anchors.verticalCenter: parent.verticalCenter;
                                    Label {
                                        text: format
                                        color: "#fff"
                                        fontSize: "small"
                                        anchors.centerIn: parent
                                    }
                                }
                                Rectangle {
                                    height: parent.height
                                    anchors.left: rformat.right;
                                    anchors.leftMargin: units.gu(1.6);
                                    Label {
                                        text: size
                                        anchors.verticalCenter: parent.verticalCenter
                                    }
                                }

                                onClicked: {
                                    PopupUtils.open(dialog)
                                    single.download(link);
                                }
                            }
                        }
                        Scrollbar {
                            flickableItem: urlView
                            align: Qt.AlignTrailing
                        }
                    }

                    SingleDownload {
                        id: single
                    }

                    Component {
                        id: dialog
                        Dialog {
                            id: dialogue
                            title: i18n.tr("Downloading")
                            text: page1.title
                            ProgressBar {
                                minimumValue: 0
                                maximumValue: 100
                                value: single.progress
                            }
                            Connections {
                                target: single
                                onFinished: {
                                    PopupUtils.close(dialogue)
                                    //console.log(path)
                                    root.contentTransfer = [];
                                    root.transferItemList = [transferComponent.createObject(root, {"url": path}) ]
                                    root.contentTransfer.items = root.transferItemList;
                                    root.contentTransfer.state = ContentTransfer.Charged;

                                    var importItems = root.contentTransfer.items;

                                    PopupUtils.open(downloadDialog, pageStack, {"contentType" : ContentType.Videos, "downloadId" : single.downloadId, "path" : path});
                                }
                            }
                            Button {
                                text: i18n.tr("Cancel")
                                color: UbuntuColors.red
                                onClicked: {
                                    single.cancel()
                                    PopupUtils.close(dialogue)
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}

